==> v0.3.0.zip: epervier-old/examples/basic/test_scene2/init.lua <==
-- scenes/test :: a basic test scene

--[[
  Copyright © 2019 Kazhnuz

  Permission is hereby granted, free of charge, to any person obtaining a copy of
  this software and associated documentation files (the "Software"), to deal in
  the Software without restriction, including without limitation the rights to
  use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of
  the Software, and to permit persons to whom the Software is furnished to do so,
  subject to the following conditions:

  The above copyright notice and this permission notice shall be included in all
  copies or substantial portions of the Software.

  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS
  FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR
  COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
  IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
  CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
]]

local Scene = require "gamecore.modules.scenes"
local TestScene = Scene:extend()

local folder = "examples/basic/test_scene2/"

local World   = require "gamecore.modules.world.baseworld"

function TestScene:new()
  TestScene.super.new(self)

  self.assets:addImage("debris", folder .. "assets/debris.png")
  self.assets:addSprite("poof", folder .. "assets/poof")
  self.assets:addTileset("weapon", folder .. "assets/weapon")

  self.i = 0
  self.estImpair = false

  self.world = World(self, "examples.basic.test_scene2.actors")
  self.world:newActor("explosion", 12, 12)
  self.world:newActor("explosion", 1, 78)
  self.world:newActor("explosion", 40, 200)
end

function TestScene:update(dt)
  self.i = self.i + dt

  local i = math.floor(self.i)

  self.estImpair = (math.floor(i / 2) ~= (i / 2))

  self.world:update(dt)
end

function TestScene:mousepressed(x, y)
  core.scenemanager:setStoredScene("pausedScene")
end


function TestScene:draw()
  love.graphics.setColor(.4, 0, 0, 1)
  love.graphics.rectangle("fill", 0, 0, 424, 240)

  love.graphics.setColor(1, 1, 1, 1)
  love.graphics.print(math.floor(self.i) .. " ; " .. self.mouse.x .. ":" .. self.mouse.y .. ":" .. self.world:countActors(), 16, 16)

  if self.estImpair then
    self.assets.images["debris"]:draw(16, 32)
    self.assets.tileset["weapon"]:drawTile(3, 32, 32)
    self.assets.sprites["poof"]:drawAnimation(64, 32)
  else
    love.graphics.setColor(0, 1, 0, 1)
    self.assets.images["debris"]:drawMask(16, 32)
    self.assets.tileset["weapon"]:drawTileMask(3, 32, 32)
    self.assets.sprites["poof"]:drawAnimationMask(64, 32)

    utils.graphics.resetColor()
  end

  self.world:draw()
end

return TestScene

==> v0.5.0.zip: epervier-old/examples/basic/test_scene2/init.lua <==
-- scenes/test :: a basic test scene

--[[
  Copyright © 2019 Kazhnuz

  Permission is hereby granted, free of charge, to any person obtaining a copy of
  this software and associated documentation files (the "Software"), to deal in
  the Software without restriction, including without limitation the rights to
  use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of
  the Software, and to permit persons to whom the Software is furnished to do so,
  subject to the following conditions:

  The above copyright notice and this permission notice shall be included in all
  copies or substantial portions of the Software.

  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS
  FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR
  COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
  IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
  CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
]]

local Scene = require "gamecore.modules.scenes"
local TestScene = Scene:extend()

local folder = "examples/basic/test_scene2/"

local World   = require "gamecore.modules.world.baseworld"

function TestScene:new()
  TestScene.super.new(self)

  self.assets:batchImport("examples.basic.test_scene2.assets")

  self.i = 0
  self.estImpair = false

  World(self, "examples.basic.test_scene2.actors")

  self.world:newActor("explosion", 12, 12)
  self.world:newActor("explosion", 1, 78)
  self.world:newActor("explosion", 40, 200)

  self.world:loadMap()
end

function TestScene:update(dt)
  self.i = self.i + dt

  local i = math.floor(self.i)

  self.estImpair = (math.floor(i / 2) ~= (i / 2))
end

function TestScene:mousepressed(x, y)
  core.scenemanager:setStoredScene("pausedScene")
end


function TestScene:drawStart()
  love.graphics.setColor(.4, 0, 0, 1)
  love.graphics.rectangle("fill", 0, 0, 424, 240)
  utils.graphics.resetColor()
end

function TestScene:drawEnd()
  love.graphics.setColor(1, 1, 1, 1)
  love.graphics.print(math.floor(self.i) .. " ; " .. self.mouse.x .. ":" .. self.mouse.y .. ":" .. self.world:countActors(), 16, 16)

  if self.estImpair then
    self.assets.images["debris"]:draw(16, 32)
    self.assets.tileset["weapon"]:drawTile(3, 32, 32)
    self.assets.sprites["poof"]:drawAnimation(64, 32)
  else
    love.graphics.setColor(0, 1, 0, 1)
    self.assets.images["debris"]:drawMask(16, 32)
    self.assets.tileset["weapon"]:drawTileMask(3, 32, 32)
    self.assets.sprites["poof"]:drawAnimationMask(64, 32)

    utils.graphics.resetColor()
  end
end

return TestScene
